@@ -142,6 +142,7 @@ def generate_options(function, description: str = "No description.") -> List['Op
 
 class BaseCommand:
     __permissions__: list = []
+    all_guilds: bool = False
     def __repr__(self) -> str:
         return "<appcommands.core.{0.__class__.__name__} name={0.name} description={1}>".format(self, self.description)
 
@@ -543,7 +544,7 @@ class Choice:
 
 
 class Option:
-    """Options for slashcommands that you
+    """Options for slashcommands
     
     Parameters 
     ------------
@@ -641,6 +642,7 @@ class SlashCommand(BaseCommand):
         self.guild_ids: List[int] = guild_ids
         self.cog = None
         self.type: int = 1
+        self.parent=None
         self.is_subcommand = False
         if callback:
             if not asyncio.iscoroutinefunction(callback):
@@ -703,6 +705,12 @@ class SlashCommand(BaseCommand):
     def __repr__(self) -> str:
         return "<SlashCommand name={0.name} description={0.description} options={0.options}>".format(self)
 
+    @property
+    def full_name(self):
+        if not self.parent: return self.name
+        if not self.parent.parent: return self.parent.name + " " + self.name
+        return self.parent.parent.name + " " + self.parent.name + " " + self.name
+
 class SubCommandGroup(BaseCommand):
     """SubCommand wrapper class
 
@@ -767,7 +775,7 @@ class SubCommandGroup(BaseCommand):
             if not asyncio.iscoroutinefunction(func):
                 raise TypeError('Callback must be a coroutine.')
             command = cls(*args, callback=func, **kwargs)
-            command.is_subcommand = True
+            command.is_subcommand, command.parent = True, self
             command.__func__ = func
             self.subcommands.append(command)
             return command
